<!DOCTYPE html>
<html lang="en">

<head>

  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
  <meta name="description" content="">
  <meta name="author" content="">

  <title>New Century Healthcare</title>

  <!-- Bootstrap core CSS -->
  <link href="vendor/bootstrap/css/bootstrap.min.css" rel="stylesheet">

  <!-- Custom fonts for this template -->
  <link href="vendor/fontawesome-free/css/all.min.css" rel="stylesheet">
  <link href="vendor/simple-line-icons/css/simple-line-icons.css" rel="stylesheet" type="text/css">
  <link href="https://fonts.googleapis.com/css?family=Lato:300,400,700,300italic,400italic,700italic" rel="stylesheet" type="text/css">

  <!-- Custom styles for this template -->
  <link href="css/landing-page.min.css?rnd=11" rel="stylesheet">
  <link href="css/custom.css?rnd=11" rel="stylesheet">
</head>

<body>

  <!-- Navigation -->
  <!-- <nav class="navbar navbar-light bg-light static-top"> -->
  <nav class="navbar navbar-light bg-color2 static-top">
  <!--   <div class="container">
      <a class="navbar-brand" href="#">Start Bootstrap<img src=./img/logo.png></a>
      <a class="btn btn-primary" href="#">Sign In</a>
    </div> -->

   <!--  <div class="divpagelogo">
      <a href="/">
        <img src="./img/logo.png" style="width: 100%;height: auto;">
      </a>
    </div> -->
  </nav>
<!-- <div class="container ">
  <div class="row">
    <div class="col-md-12 redbr" style="padding-left: 0px!important;padding-right: 0px!important;" >
      <div style="width: 23%;height: 117px;text-align: center;display: inline-block;" class="redbr">
         <img src="./img/logo.png" >
      </div>
      <div style="margin-left: 3%;width: 11%;height: 114px;display: inline-block;text-align: center;" class="redbr" >
          <p style="color: #979797;"><b>網站首頁</b></p>
      </div>
      <div style="width: 11%;height: 114px;display: inline-block;margin-top: 0px;text-align: center;" class="redbr">
          <p style="color: #979797;"><b>關於我們</b></p>
      </div>
      <div style="width: 11%;height: 114px;display: inline-block;text-align: center;" class="redbr">
          <p style="color: #979797;"><b>醫療中心</b></p>
      </div>
      <div style="width: 11%;height: 114px;display: inline-block;text-align: center;" class="redbr">
          <p style="color: #979797;"><b>兒童發展</b></p>
      </div>
      <div style="width: 11%;height: 114px;display: inline-block;text-align: center;" class="redbr">
          <p style="color: #979797;"><b>兒科知識</b></p>
      </div>
      <div style="width: 11%;height: 114px;display: inline-block;text-align: center;" class="redbr">
          <p style="color: #979797;"><b>查詢預約</b></p>
      </div>
      <div style="width: 1.8%;height: 114px;display: inline-block;text-align: center;margin-left: 1.3%" class="redbr">
          <p style="color: #979797;"><b>繁</b></p>
      </div>
      <div style="width: 1.8%;height: 114px;display: inline-block;text-align: center;margin-left: 0.5%" class="redbr">
          <p style="color: #979797;"><b>簡</b></p>
      </div>
    </div>
  </div>
</div> -->

<div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;position: relative;" >
          <style>
    /*#link_bar li:hover a { color: red }*/
    /*#link_bar li:hover  a p b { color: #a03d49; }*/
    #link_bar li:hover  a p b { color: #a03d49; }
    /*#link_bar li:hover  { border-top:2px solid #a03d49; }*/

     /*#link_bar li { border-top:2px solid transparent;cursor: pointer; }*/
     #link_bar li { border-top:2px solid transparent; }
    #link_bar li:hover  { border-top:2px solid #a03d49; }
</style>
          <ul class="horizontal " id="link_bar" style="list-style-type: none;
            margin: 0;
            padding: 0;">
              <div style="width: 23%;height: 117px;text-align: center;display: inline-block;vertical-align:top;" >
                <a href="javascript:void(0)"> <img src="./img/logo.png" ></a>
              </div>
              
               <li style="margin-left: 3%;width: 10%;height: 114px;display: inline-block;text-align: center;vertical-align:top;padding-top:38px"  >
                 
                <p style="color: #979797;"><b>網站首頁</b></p>
                 
              </li>
             
               <li style="width: 10%;height: 114px;display: inline-block;margin-top: 0px;text-align: center;padding-top:38px;" >
                <p style="color: #979797;"><b>關於我們</b></p>
              </li>

              <li style="width: 10%;height: 114px;display: inline-block;text-align: center;padding-top:38px;cursor: pointer;" >
                <a href="nchmc-v-hkdescrip.php" style="text-decoration: none;display: inline-block;
    width: 100%;height: 100%;" > 
                  <p style="color: #979797;"><b>醫療中心</b></p>
                  </a>
              </li>
              <li style="width: 10%;height: 114px;display: inline-block;text-align: center;padding-top:38px;" >
                  <p style="color: #979797;"><b>兒童發展</b></p>
              </li>
              <li style="width: 10%;height: 114px;display: inline-block;text-align: center;padding-top:38px;" >
                  <p style="color: #979797;"><b>兒科知識</b></p>
              </li>
              <li style="width: 10%;height: 114px;display: inline-block;text-align: center;padding-top:38px;" >
                  <p style="color: #979797;"><b>查詢預約</b></p>
              </li>
              <div style="width: 1.8%;height: 114px;display: inline-block;text-align: center;padding-top:38px;margin-left: 1.3%" >
                  <p style="color: #979797;"><b>繁</b></p>
              </div>
              <div style="width: 1.8%;height: 114px;display: inline-block;text-align: center;padding-top:38px;margin-left: 0.5%" >
                  <p style="color: #979797;"><b>簡</b></p>
              </div>
          </ul>
             

     </div>
  </div>
</div>  

  <!-- Masthead -->
  <header style="position: relative;
    background-color: #343a40;
    background: url(../img/contactbanner.png) no-repeat center center;
    background-size: cover;">
    <div style="height: 320px">
    </div>
  </header>
  <div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;text-align: center;" > 
        <h5 style="position: absolute;margin-bottom: 5px;margin-top: 310px;text-align: center;color: #838c96;width: 100%" ><b>查詢預約</b></h5>
      </div>
    </div>
  </div>


   

  

<!--    <span style="width:100vw;height: 1px;background: #dddddd;position: absolute;display: inline-block;top: 0px;margin-top: 30px;" ></span>
 -->
<!--   <div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="height: 60px ;position: relative;width:100%"> -->
          <!-- place horizontal line -->
     <!--      <span style="width:10000px;height: 1px;background: #dddddd;position: absolute;display: inline-block;left: 50%;margin-left: -190px;top: 0px;margin-top: 30px;" ></span> -->
    <!--  <h5 style="position: absolute;margin-bottom: 5px;margin-top: 310px;text-align: center;color: #838c96;width: 100%" ><b>查詢預約</b></h5>
        <span style="width:100%;height: 1px;background: #dddddd;position: absolute;display: inline-block;top: 0px;margin-top: 30px;" ></span>
        </div>
    </div>
    </div>
  </div> -->
  <div class="container ">
    <div class="row">
      <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" >
          <div style="display: block;width: 100%;text-align: left; margin-top: 36px;margin-left: 18px;">
              <p><span style="color:#2c2c2c;">首頁 > </span><span style="color:#a73745; ">查詢預約</span></p>

          </div>
      </div>
    </div>
  </div>

  <div class="container ">
    <div class="row">
      <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" >
          <div style="display: block;width: 100%;text-align: center;">
              <h4><span style="color:#a73745; ">查 詢 預 約</span></h4>

          </div>
      </div>
    </div>
  </div>


     <!-- horizontal line -->
  <div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="height: 60px ;position: relative;width:100%">
          <!-- place horizontal line -->
     <!--      <span style="width:10000px;height: 1px;background: #dddddd;position: absolute;display: inline-block;left: 50%;margin-left: -190px;top: 0px;margin-top: 30px;" ></span> -->
        <span style="width:100%;height: 1px;background: #dddddd;position: absolute;display: inline-block;top: 0px;margin-top: 30px;" ></span>
        </div>
    </div>
    </div>
  </div>
  <!-- end horizontal line -->

    <div class="container ">
    <div class="row">
      <div class="col-md-8 " style="padding-left: 0px!important;padding-right: 0px!important;" >
  <iframe width='100%' height='auto' style="min-height: 460px;" frameborder='0' scrolling='no' marginheight='0' marginwidth='0' src='https://maps.google.com.tw/maps?f=q&hl=zh-TW&geocode=&q=香港九龍尖沙咀海港城海洋中心&z=18&output=embed&t='></iframe>
          <!-- table -->
          <table width="100%">
            <tr style="background-color: #b9616b;height: 36px;">
              <td style="width: 23%;border:1px solid white; " valign="middle">
                <p style="color: white;margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">中心</p>
              </td>

              <td style="width: 35%;border:1px solid white;">
                <p style="color: white;margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">營業時間</p>
              </td>
              <td style="width: 42%;border:1px solid white;">
                 <p style="color: white;margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">地址</p>
              </td>
            </tr>
            <tr style="background-color: #f6f6f6;height: 36px;vertical-align: top;">
              <td style="border:1px solid white;">
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">新世紀香港醫療中心</p>
              </td>
              <td style="border:1px solid white;">
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">星期一至五:</p>
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">上午9:00-13:00/下午14:00-18:00</p>
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">星期六:</p>
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">上午9:00-13:00(下午休息)</p>
                <p style="margin-left: 25px;margin-bottom: 1rem!important;font-size: 15px;">星期日及公眾假期:休息</p>
              </td>
              <td style="border:1px solid white;">
                 <p style="line-height: 36px;margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">香港九龍尖沙咀海港城海洋中心1328-29室</p>
              </td>
            </tr>

             <tr style="background-color: #f6f6f6;height: 36px;vertical-align: top;">
              <td style="border:1px solid white;">
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">新世紀兒童發展中心</p>
              </td>
              <td style="border:1px solid white;">
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">星期一至六:</p>
                <p style="margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">上午9:00-12:30 / 下午13:30-18:30</p>
                <p style="margin-left: 25px;margin-bottom: 1rem!important;font-size: 15px;">星期日及公衆假期： 休息</p>
                
              </td>
              <td style="border:1px solid white;">
                 <p style="line-height: 36px;margin-left: 25px;margin-bottom: 0rem!important;font-size: 15px;">香港九龍尖沙咀海港城海洋中心1330室</p>
              </td>
            </tr>
          </table>
          <!-- end table -->

      </div>
        <div class="col-md-4 " style="padding-left: 30px!important;padding-right: 0px!important;" >
              <!-- right column  -->
                <div style="width: 100%;text-align: center;margin-bottom: 18px;">
                  <h5><span style="color:#a73745; ">新世紀香港醫療中心</span></h5>
                </div>
                <div style="display: inline-block;width: 49%;background-color: #c38899;float: left;">
                  <a href="tel:+85228860066" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                    <div style="display: inline-block;vertical-align: top;padding-top: 20px;padding-left: 3px;">
                      <img src="./img/telephonesmall2.png">
                    </div>
                    <div style="display: inline-block; margin-left: 5px;padding-top: 20px;padding-bottom:20px;padding-right: 1px;">
                        <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">電 話 諮 詢</p>
                         <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">+852 2886 0066</p>
                    </div>
                  </a>
                </div>
                <div style="display: inline-block;width: 49%;background-color: #88c3bc;float: left;">
                  <a href="https://api.whatsapp.com/send?phone=85267065853" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                    <div style="display: inline-block;vertical-align: top;padding-top: 20px;padding-left: 3px;">
                      <img src="./img/whatappsmall2.png">
                    </div>
                    <div style="display: inline-block; margin-left: 5px;padding-bottom:20px;padding-right: 1px;padding-top: 20px;">
                        <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">WHATSAPP</p>
                         <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">+852 6706 5853</p>
                    </div>
                  </a>
                </div>

                <div style="display: inline-block;width: 49%;background-color: #c5a489;float: left;">
                  <a href="mailto:info@ncich.com.hk" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                    <div style="display: inline-block;vertical-align: top;padding-top: 20px;padding-left: 3px;">
                      <img src="./img/mailsmall2.png">
                    </div>
                    <div style="display: inline-block; margin-left: 5px;padding-bottom:23px;padding-right: 1px;padding-top: 20px;">
                        <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">電 郵 諮 詢</p>
                         <p style="margin-bottom: 0rem!important;font-size: 13px;color: white;">info@ncich.com.hk</p>
                    </div>
                  </a>
                </div>
                <div style="display: inline-block;width: 49%;background-color: #88a0c3;float: left;">
                  <a href="https://www.facebook.com/pages/category/Medical-Service/New-Century-%E6%96%B0%E4%B8%96%E7%B4%80%E9%A6%99%E6%B8%AF%E9%86%AB%E7%99%82%E4%B8%AD%E5%BF%83-102129377831833/" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                    <div style="display: inline-block;vertical-align: top;padding-top: 11px;padding-left: 3px;">
                      <img src="./img/facebooksmall2.png">
                    </div>
                    <div style="display: inline-block; margin-left: 5px;padding-bottom:11px;padding-right: 1px;padding-top: 10px;">
                        <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">Facebook</p>
                         <p style="margin-bottom: 0rem!important;font-size: 15px;color: white;">New Century</p>
                         <p style="margin-bottom: 0rem!important;font-size: 13px;color: white;">新世紀香港醫療中心</p>
                    </div>
                  </a>
                </div>


            <div class="container ">
              <div class="row">
               <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
                  

                 <div style="width: 100%;text-align: center;margin-bottom: 0px;margin-top: 16px;">
                  <div style="display: inline-block;">
                  <img src="./img/contactncichqr1.png" style="max-width: 134px;max-height: 139px;">
                  </div>
                  <div style="display: inline-block;">
                    <p style="line-height: 139px;">關注微信及時了解健康資訊</p>
                  </div>
                </div>

                </div>
              </div>
            </div>

                   <div style="height: 10px ;position: relative;width:100%">
                    <!-- place horizontal line -->
               <!--      <span style="width:10000px;height: 1px;background: #dddddd;position: absolute;display: inline-block;left: 50%;margin-left: -190px;top: 0px;margin-top: 30px;" ></span> -->
                  <span style="width:100%;height: 1px;background: #dddddd;position: absolute;display: inline-block;top: 0px;margin-top: 15px;" ></span>
                  </div>

                  <!-- bottom address -->
                    <div style="width: 100%;text-align: center;margin-bottom: 18px;margin-top: 34px;">
                      <h5><span style="color:#a73745; ">新世紀兒童發展中心</span></h5>
                    </div>
                    <div style="display: inline-block;width: 49%;background-color: #c38899;float: left;">
                      <a href="tel:+85228862382" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                        <div style="display: inline-block;vertical-align: top;padding-top: 20px;padding-left: 3px;">
                          <img src="./img/telephonesmall2.png">
                        </div>
                        <div style="display: inline-block; margin-left: 5px;padding-top: 20px;padding-bottom:20px;padding-right: 1px;">
                            <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">電 話 諮 詢</p>
                             <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">+852 2886 2382</p>
                        </div>
                      </a>
                    </div>
                    <div style="display: inline-block;width: 49%;background-color: #88c3bc;float: left;">
                      <a href="https://api.whatsapp.com/send?phone=85268582565" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                        <div style="display: inline-block;vertical-align: top;padding-top: 20px;padding-left: 3px;">
                          <img src="./img/whatappsmall2.png">
                        </div>
                        <div style="display: inline-block; margin-left: 5px;padding-bottom:20px;padding-right: 1px;padding-top: 20px;">
                            <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">WHATSAPP</p>
                             <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">+852 6858 2565</p>
                        </div>
                      </a>
                    </div>

                    <div style="display: inline-block;width: 49%;background-color: #c5a489;float: left;">
                      <a href="mailto:cdc@ncich.com.hk" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                        <div style="display: inline-block;vertical-align: top;padding-top: 20px;padding-left: 3px;">
                          <img src="./img/mailsmall2.png">
                        </div>
                        <div style="display: inline-block; margin-left: 5px;padding-bottom:23px;padding-right: 1px;padding-top: 20px;">
                            <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">電 郵 諮 詢</p>
                             <p style="margin-bottom: 0rem!important;font-size: 13px;color: white;">cdc@ncich.com.hk</p>
                        </div>
                      </a>
                    </div>
                    <div style="display: inline-block;width: 49%;background-color: #88a0c3;float: left;">
                      <a href="https://www.facebook.com/pages/category/Education/New-Century-%E6%96%B0%E4%B8%96%E7%B4%80%E5%85%92%E7%AB%A5%E7%99%BC%E5%B1%95%E4%B8%AD%E5%BF%83-115578896475556/" style="display: block;width: 100%;height: 100%;text-decoration: none;">
                        <div style="display: inline-block;vertical-align: top;padding-top: 11px;padding-left: 3px;">
                          <img src="./img/facebooksmall2.png">
                        </div>
                        <div style="display: inline-block; margin-left: 5px;padding-bottom:11px;padding-right: 1px;padding-top: 10px;">
                            <p style="margin-bottom: 0rem!important;font-size: 17px;color: white;">Facebook</p>
                             <p style="margin-bottom: 0rem!important;font-size: 15px;color: white;">New Century</p>
                             <p style="margin-bottom: 0rem!important;font-size: 13px;color: white;">新世紀兒童發展中心</p>
                        </div>
                      </a>
                    </div>


                <div class="container ">
                  <div class="row">
                   <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
                      

                     <div style="width: 100%;text-align: center;margin-bottom: 0px;margin-top: 16px;">
                      <div style="display: inline-block;">
                      <img src="./img/contactncichqr1.png" style="max-width: 134px;max-height: 139px;">
                      </div>
                      <div style="display: inline-block;">
                        <p style="line-height: 139px;">關注微信及時了解健康資訊</p>
                      </div>
                    </div>

                    </div>
                  </div>
                </div>
                  <!-- end bottom address -->

              <!-- end right column -->
        </div>  
    </div>
  </div>

 


     <div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="position: relative;width:100%">
          <!-- place horizontal line -->
     <!--      <span style="width:10000px;height: 1px;background: #dddddd;position: absolute;display: inline-block;left: 50%;margin-left: -190px;top: 0px;margin-top: 30px;" ></span> -->
        <img src="../img/samplecontact2.png" width="100%">
        </div>
    </div>
    </div>
  </div>


  

  

  <!-- end center graph -->

  
    <!-- footer -->
    <div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="height: 60px ;position: relative;width:100%">
          <!-- place horizontal line -->
     <!--      <span style="width:10000px;height: 1px;background: #dddddd;position: absolute;display: inline-block;left: 50%;margin-left: -190px;top: 0px;margin-top: 30px;" ></span> -->
        <span style="width:100%;height: 1px;background: #dddddd;position: absolute;display: inline-block;top: 0px;margin-top: 30px;" ></span>
        </div>
    </div>
    </div>
  </div>

  <div class="container ">
  <div class="row">
    <div class="col-md-6 col-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="width: 24%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">關於我們<p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">中心介紹</p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">醫療團隊</p>
          </div>
          <div style="display: block;margin-top: 18px;">
             <p style="color: #989898;margin-bottom: 0rem;">歷史背景</p>
          </div>
           <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">診所環境</p>
          </div>
        </div>
        <div style="width: 24%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">醫療中心<p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">疫苗服務</p>
          </div>
          
        </div>
        <div style="width: 24%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">兒童發展<p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div>
          
        </div>
        <div style="width: 24%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">兒科知識<p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div>
          
        </div>
    </div>
    <div class="col-md-6 col-12 " style="padding-left: 10px!important;padding-right: 0px!important;" >

      <table>
        <tr>
          <td width="90%">  <p style="color: #a64a55;margin-bottom: 0rem;">新世紀香港醫療中心</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">地址：香港九龍尖沙咀海港城海洋中心1328-29 室</p> </td>
          
          <td rowspan="5"> <img src="../img/qrcode1.png" width="90px" height="90px"></td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">電話：+852 2886 0066</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">電郵：info@ncich.com.hk</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">WhatsApp: 6706 5853</p> </td>
        </tr>
         <tr>
          <td width="90%" >  <br><p style="color: #a64a55;margin-bottom: 0rem;">新世紀兒童發展中心</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">地址：香港九龍尖沙咀海港城海洋中心1330室</p> </td>
          
          <td rowspan="5"> <img src="../img/qrcode2.png" width="90px" height="90px"></td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">電話：+852 2886 2382</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">WhatsApp: 6858 2565</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">WeChat: NEWCENTURY_CDC_TST</p> </td>
        </tr>
      </table>  
     
     <!--    <div style="width: 100%;display: block;" class="redbr">
         <p style="color: #a64a55;margin-bottom: 0rem;">新世紀香港醫療中心</p> 
          <div style="display: inline-block;float: left;">
            <p style="color: #989898;margin-bottom: 0rem;">地圵:</p>
            <p style="color: #989898;margin-bottom: 0rem;">電話:</p>
            <p style="color: #989898;margin-bottom: 0rem;">電郵:</p>
            <p style="color: #989898;margin-bottom: 0rem;">WhatApp:</p>
          </div>
          <div style="display: inline-block;float: right;">
              <img src="../img/qrcode1.png" width="90px" height="90px">
          </div>

         </div> -->
    </div>
 </div>
</div>
<div class="row" style="height: 70px;background-color: #a64a55;text-align: center;">
  <div style="height: 100%;vertical-align: center;width: 100%;text-align: center;"  >
  <p style="width: 100%;color: white;margin-top: 20px;">@2005-2019 新世紀香港醫療中心</p>
  <!-- <p style="width: 100%;color: white;margin-top: 30px;">©2005-2019 新世紀香港醫療中心</p> -->
  </div>
</div>
  <!-- end footer -->


  </footer>

  <!-- Bootstrap core JavaScript -->
  <script src="vendor/jquery/jquery.min.js"></script>
  <script src="vendor/bootstrap/js/bootstrap.bundle.min.js"></script>

</body>

</html>
